@@ -16,7 +16,7 @@ class Admin(Blueprint):
                 doc = inspect.getdoc(function_called)
                 route[http_method] = {
                     'doc': doc if doc else '',
-                    'signature': str(inspect.signature(function_called.__class_func__))
+                    'signature': get_signature(function_called.__class_func__)
                 }
             routes[resource_path] = route
         return routes
@@ -24,3 +24,20 @@ class Admin(Blueprint):
     def get_context(self):
         """Returns the calling context."""
         return self.current_request.to_dict()
+
+
+def get_signature(func):
+    sig = ""
+    params = inspect.signature(func).parameters
+    index = 0
+    for k, p in params.items():
+        index += 1
+        if index == 1:
+            continue
+        sp = k
+        if p.annotation != inspect.Parameter.empty:
+            sp = f"{sp}:{str(p.annotation.__name__)}"
+        if p.default != inspect.Parameter.empty:
+            sp = f"{sp}='{p.default}'" if type(p.default) == str else f"{sp}={p.default}"
+        sig = f"{sp}" if index == 2 else f"{sig}, {sp}"
+    return f"({sig})"
